/*  FBI_Annual_Assault_Arrests_BigORI.sas	*/
options nocenter ps=60 ls=72;
libname  sas  '/jackie/jc63/fbidata/';

filename  in1  '/jackie/jc63/fbidata/FBI-Assault-arrests-big-ori.csv';
filename  out1 '/jackie/jc63/fbidata/FBI-Annual-Assault-arrests-bigORI.csv';
filename  out2 
'/jackie/jc63/fbidata/Check-FBI-Annual-Assault-arrests-bigORI.csv';
filename  out3 
'/jackie/jc63/fbidata/FBI-Annual-Assault-arrests-bigORI-all8797.csv';

data fbimonth;
length AgencyNm $ 35;
length agency $ 15;
length ori $ 7;
length id_group $ 2;
infile in1 dsd missover lrecl=300;
input
	ORI  $
	ID_GROUP $
	YEAR
	AGENCYNM  $
	MONTH
	OFFENSE
	POPN
	arradlt
	arrjuv
	arrjvm
	arradm
	arrjvf
	arradf
	;
arrmale = arrjvm + arradm;
arrfem  = arrjvf + arradf;
arrtotsx= arrmale + arrfem;
arrtotag= arradlt + arrjuv;

nomatch = .;
if arrtotsx ne arrtotag then nomatch = 1;
else if arrtotsx = arrtotag then nomatch = 0;

agency = trim(left(agencynm));
index = ori||offense||year;
run;
 
proc sort data=fbimonth;
by offense year month;
run;

proc freq data=fbimonth;
table year*offense / list nopercent norow nocol;;
title 'Number ORI-months per year';
run;

proc freq data=fbimonth;
table year*nomatch / list nopercent norow nocol;;
title 'Differences in arrest monthly counts by sex and by age';
run;

proc sort data=fbimonth;
by offense ori agency year month;
run;


data month;
set fbimonth;
if (agency="COLUMBUS" and ori="OHCOP00") 
or (agency="PHOENIX" and ori="AZ00723");
if (year = 87) or (year = 97);
run;
proc print data=month;
var ori agency offense year month arrtotsx arrtotag;
title 'Sample Monthly Data Extract';
run;


data fbiyear;
set fbimonth;
by  offense ori agency year month;
if first.year then fyear=1; else fyear=0;
if last.year then lyear=1; else lyear=0;
if first.year then do;
   mosrept = 0;
   arrtot1 = 0;
   arrtot2 = 0;
end;
flag = 0;
mosrept + 1;
arrtot1 + arrtotsx;
arrtot2 + arrtotag;
if last.year then do;
   flag = 1;
lastmon = month;
   output;
end;
run;

data year;
set fbiyear;
if (agency="COLUMBUS" and ori="OHCOP00") 
or (agency="PHOENIX" and ori="AZ00723");
if (year = 87) or (year = 97);
run;
proc print data=year;
var ori agency offense year mosrept arrtotsx arrtotag arrtot1 arrtot2;
title 'Sample Yearly Data Extract';
run;

proc freq data=fbiyear;
table year*mosrept*lastmon / list nopercent norow nocol;
title 'Frequency of agencies by months reported each year';
run;

proc sort data=fbiyear;
by offense ori agency year;
run;


data aggarryr (keep=aggoff ori agency year aggmos aggarrsx aggarrag);
set fbiyear;
if (offense=4) and (year>86) and (year<98);
aggoff=offense;
aggmos=mosrept;
aggarrsx=arrtot1;
aggarrag=arrtot2;

proc sort data=aggarryr;
by ori agency year;
run;

data simarryr (keep=simoff ori agency year simmos simarrsx simarrag);
set fbiyear;
if (offense=8) and (year>86) and (year<98);
simoff=offense;
simmos=mosrept;
simarrsx=arrtot1;
simarrag=arrtot2;

proc sort data=simarryr;
by ori agency year;
run;

/* ORIs with full year data both agg and simple assault */
data fullarr;
merge aggarryr (in=a) simarryr (in=b);
by ori agency year;
if a or b;

data _null_;
set fullarr;
file out3;
put 
	agency	','
	ori	','
	year	','
	aggoff	','
	aggmos	','
	aggarrsx ','
	aggarrag ','
        simoff	','
	simmos	','
	simarrsx ','
	simarrag
	;


data aggassyr (keep=aggoff ori agency year aggmos aggarrsx aggarrag);
set fbiyear;
if (offense=4) and (year>86) and (year<98) and (mosrept=12);
aggoff=offense;
aggmos=mosrept;
aggarrsx=arrtot1;
aggarrag=arrtot2;

proc sort data=aggassyr;
by ori agency year;
run;

data simassyr (keep=simoff ori agency year simmos simarrsx simarrag);
set fbiyear;
if (offense=8) and (year>86) and (year<98) and (mosrept=12);
simoff=offense;
simmos=mosrept;
simarrsx=arrtot1;
simarrag=arrtot2;

proc sort data=simassyr;
by ori agency year;
run;

data noaggyr;
merge aggassyr (in=a) simassyr (in=b);
by ori agency year;
if b and not a;

proc print data=noaggyr;
var ori agency year simoff simmos simarrsx simarrag;
title 'Agencies with 12 mos simple ass and <12 mos agg ass';

data nosimyr;
merge aggassyr (in=a) simassyr (in=b);
by ori agency year;
if a and not b;

proc print data=nosimyr;
var ori agency year aggoff aggmos aggarrsx aggarrag;
title 'Agencies with 12 mos agg ass and <12 mos simple ass';

/* ORIs with full year data both agg and simple assault */
data fullyear;
merge aggassyr (in=a) simassyr (in=b);
by ori agency year;
if a and b;

data _null_;
set fullyear;
file out2;
put 
	agency	','
	ori	','
	year	','
	aggoff	','
	aggmos	','
	aggarrsx ','
	aggarrag ','
        simoff	','
	simmos	','
	simarrsx ','
	simarrag
	;
	
proc sort data=fullyear;
by agency ori year;
run;

proc freq data=fullyear;
table year;
title 'Number of ORIs with full year data both agg & simple assault';


data fyear;
set fullyear;
if (agency="COLUMBUS" and ori="OHCOP00") 
or (agency="PHOENIX" and ori="AZ00723");
if (year = 87) or (year = 97);
run;
proc print data=fyear;
var ori agency year aggoff aggmos aggarrsx aggarrag 
                    simoff simmos simarrsx simarrag;
title 'Sample ORI-Years w-12mos Data Agg & Simple Ass Extract';
run;

data cntfyear (keep=ori agency yearcnt);
set fullyear;
by agency ori year;
if first.ori then yearcnt = 0;
yearcnt + 1;
if last.ori then output;
run;

proc sort data=cntfyear;
by agency ori;
run;

proc freq data=cntfyear;
table yearcnt;
title 'Frequency of agencies by number years w-12 mos data 1987-97';
run;

data select;
set cntfyear;
if yearcnt>8;
run;

proc sort data=select;
by agency ori yearcnt;
run;


data keeper (keep=agency ori year aggoff aggmos aggarrsx aggarrag
                                  simoff simmos simarrsx simarrag);
merge select (in=a) fullyear (in=b);
by agency ori;
if a;
run;

proc freq data=keeper;
table year;
title 'Number of ORIs with >8 yrs full year data both agg & simple assault';

data kpyear;
set keeper;
if (agency="COLUMBUS" and ori="OHCOP00") 
or (agency="PHOENIX" and ori="AZ00723");
if (year = 87) or (year = 97);
run;
proc print data=kpyear;
var ori agency year aggoff aggmos aggarrsx aggarrag 
                    simoff simmos simarrsx simarrag;
title 'Sample ORI-Years >8 yrs w-12mos Data Agg & Simple Ass Extract';
run;

data _null_;
set keeper;
file out1;
put	agency	','
	ori	','
	year	','
	aggoff	','
	aggmos	','
	aggarrsx ','
	aggarrag ','
        simoff	','
	simmos	','
	simarrsx ','
	simarrag
	;


data fyr87agg;
set fbiyear;
if offense = 4 and year = 87 and mosrept = 12;
run;
proc sort data=fyr87agg;
by ori agency year;
run;

data fyr87sim;
set fbiyear;
if offense = 8 and year = 87 and mosrept = 12;
run;
proc sort data=fyr87sim;
by ori agency year;
run;

data fyr88agg;
set fbiyear;
if offense = 4 and year = 88 and mosrept = 12;
run;
proc sort data=fyr88agg;
by ori agency year;
run;

data fyr88sim;
set fbiyear;
if offense = 8 and year = 88 and mosrept = 12;
run;
proc sort data=fyr88sim;
by ori agency year;
run;

data fyr89agg;
set fbiyear;
if offense = 4 and year =89 and mosrept = 12;
run;
proc sort data=fyr89agg;
by ori agency year;
run;

data fyr89sim;
set fbiyear;
if offense = 8 and year = 89 and mosrept = 12;
run;
proc sort data=fyr89sim;
by ori agency year;
run;

data fyr90agg;
set fbiyear;
if offense = 4 and year = 90 and mosrept = 12;
run;
proc sort data=fyr90agg;
by ori agency year;
run;

data fyr90sim;
set fbiyear;
if offense = 8 and year = 90 and mosrept = 12;
run;
proc sort data=fyr90sim;
by ori agency year;
run;

data fyr91agg;
set fbiyear;
if offense = 4 and year = 91 and mosrept = 12;
run;
proc sort data=fyr91agg;
by ori agency year;
run;

data fyr91sim;
set fbiyear;
if offense = 8 and year = 91 and mosrept = 12;
run;
proc sort data=fyr91sim;
by ori agency year;
run;

data fyr92agg;
set fbiyear;
if offense = 4 and year = 92 and mosrept = 12;
run;
proc sort data=fyr92agg;
by ori agency year;
run;

data fyr92sim;
set fbiyear;
if offense = 8 and year = 92 and mosrept = 12;
run;
proc sort data=fyr92sim;
by ori agency year;
run;

data fyr93agg;
set fbiyear;
if offense = 4 and year = 93 and mosrept = 12;
run;
proc sort data=fyr93agg;
by ori agency year;
run;

data fyr93sim;
set fbiyear;
if offense = 8 and year = 93 and mosrept = 12;
run;
proc sort data=fyr93sim;
by ori agency year;
run;

data fyr94agg;
set fbiyear;
if offense = 4 and year = 94 and mosrept = 12;
run;
proc sort data=fyr94agg;
by ori agency year;
run;

data fyr94sim;
set fbiyear;
if offense = 8 and year = 94 and mosrept = 12;
run;
proc sort data=fyr94sim;
by ori agency year;
run;

data fyr95agg;
set fbiyear;
if offense = 4 and year = 95 and mosrept = 12;
run;
proc sort data=fyr95agg;
by ori agency year;
run;

data fyr95sim;
set fbiyear;
if offense = 8 and year = 95 and mosrept = 12;
run;
proc sort data=fyr95sim;
by ori agency year;
run;

data fyr96agg;
set fbiyear;
if offense = 4 and year = 96 and mosrept = 12;
run;
proc sort data=fyr96agg;
by ori agency year;
run;

data fyr96sim;
set fbiyear;
if offense = 8 and year = 96 and mosrept = 12;
run;
proc sort data=fyr96sim;
by ori agency year;
run;

data fyr97agg;
set fbiyear;
if offense = 4 and year = 97 and mosrept = 12;
run;
proc sort data=fyr97agg;
by ori agency year;
run;

data fyr97sim;
set fbiyear;
if offense = 8 and year = 97 and mosrept = 12;
run;
proc sort data=fyr97sim;
by ori agency year;
run;


data allagg (keep=ori agency);
merge fyr87agg (in=a)
      fyr88agg (in=b)
      fyr89agg (in=c)
      fyr90agg (in=d)
      fyr91agg (in=e)
      fyr92agg (in=f)
      fyr93agg (in=g)
      fyr94agg (in=h)
      fyr95agg (in=i)
      fyr96agg (in=j)
      fyr97agg (in=k);
by ori agency;
if a and b and c and d and e and f and g and h and i and j and k;
run;
/* **************************************************************** */
/*  Number of agencies with agg assault counts in all years 1987-97 */
/* **************************************************************** */

data allsim (keep=ori agency);
merge fyr87sim (in=a)
      fyr88sim (in=b)
      fyr89sim (in=c)
      fyr90sim (in=d)
      fyr91sim (in=e)
      fyr92sim (in=f)
      fyr93sim (in=g)
      fyr94sim (in=h)
      fyr95sim (in=i)
      fyr96sim (in=j)
      fyr97sim (in=k);
by ori agency;
if a and b and c and d and e and f and g and h and i and j and k;
run;
/* ******************************************************************* */
/*  Number of agencies with simple assault counts in all years 1987-97 */
/* ******************************************************************* */

data allboth (keep=ori agency);
merge fyr87sim (in=a) fyr87agg (in=aa)
      fyr88sim (in=b) fyr88agg (in=ba)
      fyr89sim (in=c) fyr89agg (in=ca)
      fyr90sim (in=d) fyr90agg (in=da)
      fyr91sim (in=e) fyr91agg (in=ea)
      fyr92sim (in=f) fyr92agg (in=fa)
      fyr93sim (in=g) fyr93agg (in=ga)
      fyr94sim (in=h) fyr94agg (in=ha)
      fyr95sim (in=i) fyr95agg (in=ia)
      fyr96sim (in=j) fyr96agg (in=ja)
      fyr97sim (in=k) fyr97agg (in=ka);
by ori agency;
if a and b and c and d and e and f and g and h and i and j and k and
aa and ba and ca and da and ea and fa and ga and ha and ia and ja and ka;
run;
/* *********************************************************************** */
/*  Number of agencies with both agg & simple assault in all years 1987-97 */
/* *********************************************************************** */

data anyagg;
merge fyr87agg (in=a)
      fyr88agg (in=b)
      fyr89agg (in=c)
      fyr90agg (in=d)
      fyr91agg (in=e)
      fyr92agg (in=f)
      fyr93agg (in=g)
      fyr94agg (in=h)
      fyr95agg (in=i)
      fyr96agg (in=j)
      fyr97agg (in=k);
by ori agency;
if a or b or c or d or e or f or g or h or i or j or k;
run;

/* **************************************************************** */
/*  Number of agencies with agg assault counts in any years 1987-97 */
/* **************************************************************** */

data anysim (keep=ori agency);
merge fyr87sim (in=a)
      fyr88sim (in=b)
      fyr89sim (in=c)
      fyr90sim (in=d)
      fyr91sim (in=e)
      fyr92sim (in=f)
      fyr93sim (in=g)
      fyr94sim (in=h)
      fyr95sim (in=i)
      fyr96sim (in=j)
      fyr97sim (in=k);
by ori agency;
if a or b or c or d or e or f or g or h or i or j or k;
run;

/* ******************************************************************* */
/*  Number of agencies with simple assault counts in any years 1987-97 */
/* ******************************************************************* */

data anyboth (keep=ori agency);
merge fyr87sim (in=a) fyr87agg (in=aa)
      fyr88sim (in=b) fyr88agg (in=ba)
      fyr89sim (in=c) fyr89agg (in=ca)
      fyr90sim (in=d) fyr90agg (in=da)
      fyr91sim (in=e) fyr91agg (in=ea)
      fyr92sim (in=f) fyr92agg (in=fa)
      fyr93sim (in=g) fyr93agg (in=ga)
      fyr94sim (in=h) fyr94agg (in=ha)
      fyr95sim (in=i) fyr95agg (in=ia)
      fyr96sim (in=j) fyr96agg (in=ja)
      fyr97sim (in=k) fyr97agg (in=ka);
by ori agency;
if a or b or c or d or e or f or g or h or i or j or k or
aa or ba or ca or da or ea or fa or ga or ha or ia or ja or ka;
run;

/* **************************************************************** */
/*  Number of agencies with simple or agg assault any years 1987-97 */
/* **************************************************************** */



