/* **************************************************** */
/*  combined_assault_arrest_offenses_ORI_codes.sas	*/
/*							*/
/*  combines big city ORI codes from FBI arrest and 	*/
/*  reported offense files				*/
/*							*/
/*  see bottom for description input data		*/
/* **************************************************** */

options nocenter ps=60 ls=72;
libname  sas  '/jackie/jc63/fbidata/';

filename inoff
'/jackie/jc63/fbidata/FBI-Annual-Assault-Offenses-bigORI-codes.csv';
filename inarr
'/jackie/jc63/fbidata/FBI-Annual-Assault-Arrests-bigORI-codes.csv';

filename outori
'/jackie/jc63/fbidata/FBI-bigORI-codes.csv';

TITLE1 'ORI Codes from FBI Arrest and Reported Offense Data';

data orioff;
length ori $ 7;
infile inoff dsd;
input  ori $;

proc sort data=orioff;
by ori;

data oriarr;
length agency $ 15;
length ori $ 7;
infile inarr dsd;
input  agency $ ori $;

proc sort data=oriarr;
by ori;


data notarr;
merge orioff (in=a) oriarr (in=b);
by ori;
if a and not b;

proc sort data=notarr;
by agency;

proc print data=notarr;
var agency ori;
title2 'ORIs missing from arrest data';


data notoff;
merge orioff (in=a) oriarr (in=b);
by ori;
if b and not a;

proc sort data=notoff;
by agency;

proc print data=notoff;
var agency ori;
title2 'ORIs missing from offense data';


data allori;
merge orioff (in=a) oriarr (in=b);
by ori;
if a or b;

proc sort data=allori;
by agency ori;

data _null_;
set allori;
file outori;
put  agency ',' ori;


/* ************************************************************ */
/*  read_FBI_yrly_assault_offenses_BigORI.sas			*/
/*                                              		*/
/*  Cumulated yearly FBI offenses counts per ORI from NCOVR	*/
/*  data center ~200 largest cities				*/
/*                                              		*/
/*  /jackie/jc63/fbidata/                       		*/
/*     FBI-yrly-assault-offenses-big-ori-w-moscnt.csv		*/
/*                                              		*/
/*  FBI_yrly_assault_offenses_BigORI.sas			*/
/*  created new output file of annual counts with unfounded	*/
/*  actual & cleared on same record for years 1987-97 only	*/
/*                                              		*/
/*  /jackie/jc63/fbidata/                       		*/
/*    FBI-Annual-Assault-offenses-bigORI-all8797.csv		*/
/*                                              		*/
/*  Above were manually edited to:              		*/
/*  1.  insert records for missing years        		*/
/*  2.  assign missing values when all counts are 0		*/
/*                                              		*/
/*  /jackie/jc63/fbidata/                       		*/
/*        FBI-Annual-Assault-offenses-bigORI-all8797-v3.csv	*/
/*								*/
/*  NOTE: resulting data include some ORI with actual offenses	*/
/*  but no data on unfounded and/or cleared offenses.		*/
/* ************************************************************ */

/* ************************************************************ */
/*  read_FBI_Annual_Assault_Arrests_BigORI.sas  		*/
/*                                              		*/
/*  Monthly FBI arrest counts per ORI obtained from NCOVR 	*/
/*  data center ~200 largest cities  				*/
/*                                              		*/
/*  /jackie/jc63/fbidata/FBI-Assault-arrests-big-ori.csv     	*/
/*                                              		*/
/*  FBI_Annual_Assault_Arrests_BigORI.sas       		*/
/*  created output file of annual counts        		*/
/*                                              		*/
/*  /jackie/jc63/fbidata/                       		*/
/*    FBI-Annual-Assault-arrests-bigORI-all8797.csv 		*/
/*                                              		*/
/*  Above were manually edited to:              		*/
/*  1.  insert records for missing years        		*/
/*  2.  identify suspect counts (usually from < 12 mos data    	*/
/*  3.  retain as NOT suspect < 12 mos counts that appear to   	*/
/*      be full year counts      				*/
/*                                              		*/
/*  /jackie/jc63/fbidata/                       		*/
/*    FBI-Annual-Assault-arrests-bigORI-all8797-v2.csv  	*/
/*								*/
/*  NOTE: resulting data include some ORI with erratic swings 	*/
/*  between aggravated (type 4)and simple assaults (type 8)  	*/
/*  possibly reflecting changes in coding practices.      	*/
/*  Totals may be more consistent time series.  		*/
/* ************************************************************ */


