/* ************************************************************ */
/*  read_FBI_Annual_Assault_Arrests_BigORI.sas                  */
/*                                                              */
/*  Monthly FBI arrest counts per ORI obtained from NCOVR       */
/*  data center ~200 largest cities                             */
/*                                                              */
/*  /jackie/jc63/fbidata/FBI-Assault-arrests-big-ori.csv        */
/*                                                              */
/*  FBI_Annual_Assault_Arrests_BigORI.sas                       */
/*  created output file of annual counts                        */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*    FBI-Annual-Assault-arrests-bigORI-all8797.csv             */
/*                                                              */
/*  Above were manually edited to:                              */
/*  1.  insert records for missing years                        */
/*  2.  identify suspect counts (usually from < 12 mos data     */
/*  3.  retain as NOT suspect < 12 mos counts that appear to    */
/*      be full year counts                                     */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*    FBI-Annual-Assault-arrests-bigORI-all8797-v2.csv          */
/*                                                              */
/*  NOTE: resulting data include some ORI with erratic swings   */
/*  between aggravated (type 4)and simple assaults (type 8)     */
/*  possibly reflecting changes in coding practices.            */
/*  Totals may be more consistent time series.                  */
/* ************************************************************ */



options nocenter ps=60 ls=72;
libname  sas  '/jackie/jc63/fbidata/';

filename  in1
'/jackie/jc63/fbidata/FBI-Annual-Assault-Arrests-bigORI-all8797-v2.csv';
filename outori
'/jackie/jc63/fbidata/FBI-Annual-Assault-Arrests-bigORI-codes.csv';

TITLE1 'Annual Counts of Assault Arrests 1987-97 200+ Largest ORIs';
 
data fbiarr;  
length agency $ 15;
length ori $ 7;
infile in1 dsd missover lrecl=300;
input
	agency	$	/*  Agency name (1st 15 characters)		*/
	ori	$	/*  Police agency ID number--state 1st 2 digits */
	year		/*  2-digit year of arrests			*/
	aggoff		/*  Offense Type 4 = aggravated assault		*/
	aggmos		/*  Total months contributing to annual count	*/
	aggarrsx 	/*  Total arrests agg ass derived from 		*/
			/*  sex-by-adult-juvenile counts		*/
	aggarrag 	/*  Total arrests agg ass derived from 		*/
			/*  Adult & Juvenile counts			*/
        simoff		/*  Offense Type 8 = simple assault		*/
	simmos		/*  Total months contributing to annual count	*/
	simarrsx	/*  Total arrests simple ass derived from 	*/
			/*  sex-by-adult-juvenile counts		*/
	simarrag 	/*  Total arrests simple ass derived from	*/
			/*  Adult & Juvenile counts			*/
	suspect		/*  Flag = 1 if count suspicious--usually < 12  */
			/*  months reporting.  NOTE < 12 mos counts 	*/
			/*  are flag = 0 when appears to be annual count*/
	;

proc sort data=fbiarr;
by agency ori;

data bigori;
set fbiarr;
by agency ori;
if first.ori;

/* title2 'FBI ORI Codes Large cities';  */
data _null_;
set bigori;
file outori;
put
	agency ','
	ori;

proc sort data=fbiarr;
by ori year;

proc freq data=fbiarr;
tables (aggmos simmos)*suspect year / list norow nocol nopercent missing;
title2 'Frequency ORIs by Year and Suspect ORI';

data check7 (keep = agency ori cntyear);
set fbiarr;
by ori;
if first.ori then cntyear = 0;
   cntyear + 1;
if last.ori then output;

data check8;
set check7;
if cntyear > 11;

data check9;
merge fbiarr (in=a) check8 (in=b);
by ori;
if b;

proc print data=check9;
var agency ori year aggoff aggmos aggarrsx aggarrag
                    simoff simmos simarrsx simarrag suspect;
title2 'records with > 11 years';


data check1 (keep=ori cntsusp);
set fbiarr;
by ori year;
if first.ori then cntsusp = 0;
   if (suspect = 1) and (aggmos = 12) and (simmos = 12) then 
   cntsusp + 1;
if last.ori then output;

data check2;
set check1;
if cntsusp > 0;

proc sort data=check2;
by ori;

data check3;
merge fbiarr (in=a) check2 (in=b);
by ori;
if b;

proc print data=check3;
var agency ori year aggoff aggmos aggarrsx aggarrag
                    simoff simmos simarrsx simarrag suspect;
title2 'records with suspect = 1 and 12 months of data';

data check4 (keep=ori cntsusp);
set fbiarr;
by ori year;
if first.ori then cntsusp = 0;
   if (suspect = 0) and ((aggmos < 12) or (simmos < 12)) then 
   cntsusp + 1;
if last.ori then output;

data check5;
set check4;
if cntsusp > 0;

proc sort data=check5;
by ori;

data check6;
merge fbiarr (in=a) check5 (in=b);
by ori;
if b;

proc print data=check6;
var agency ori year aggoff aggmos aggarrsx aggarrag
                    simoff simmos simarrsx simarrag suspect;
title2 'records with suspect = 0 and < 12 months of data';


