/* ************************************************************ */
/*  read_FBI_yrly_assault_offenses_BigORI.sas                   */
/*                                                              */
/*  Cumulated yearly FBI offenses counts per ORI from NCOVR     */
/*  data center ~200 largest cities                             */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*     FBI-yrly-assault-offenses-big-ori-w-moscnt.csv           */
/*                                                              */
/*  FBI_yrly_assault_offenses_BigORI.sas                        */
/*  created new output file of annual counts with unfounded     */
/*  actual & cleared on same record for years 1987-97 only      */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*    FBI-Annual-Assault-offenses-bigORI-all8797.csv            */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*    FBI-Annual-Assault-offenses-bigORI-all8797.csv            */
/*                                                              */
/*  Above were manually edited to:                              */
/*  1.  insert records for missing years                        */
/*  2.  assign missing values when all counts are 0             */
/*                                                              */
/*  /jackie/jc63/fbidata/                                       */
/*        FBI-Annual-Assault-offenses-bigORI-all8797-v3.csv     */
/*                                                              */
/*  NOTE: resulting data include some ORI with actual offenses  */
/*  but no data on unfounded and/or cleared offenses.           */
/* ************************************************************ */

options nocenter ps=60 ls=72;
libname  sas  '/jackie/jc63/fbidata/';

filename  in1  
'/jackie/jc63/fbidata/FBI-Annual-Assault-offenses-bigORI-all8797-v3.csv';
filename outori
'/jackie/jc63/fbidata/FBI-Annual-Assault-Offenses-bigORI-codes.csv';

TITLE1 'Annual Counts of Assault Offenses 1987-97 200+ Largest ORIs';

data fbiyrly;
length ori $ 7;
infile in1 dsd missover lrecl=300;
input
	ori		/*  FBI police agency ID			*/
	year		/*  Year of offense				*/

	ufmosrep 	/*  Number of months data for unfounded offenses*/
	ufasstot	/*  Number unfounded assaults total from FBI	*/
	ufassagg 	/*  Calculated number unfounded agg assaults:	*/
			/*  ^assagg = ^assgun+^assknife+^assoweap+^assunarm*/
	ufassall 	/*  Calculated number total assaults:		*/
			/*  ^assall = ^assagg +^asssimp			*/
	ufassgun 	/*  Number unfounded assaults w-gun		*/
	ufassknf 	/*  Number unfounded assaults w-knife		*/
	ufassowp 	/*  Number unfounded assaults w-other weapon	*/
	ufassnwp 	/*  Number unfounded assaults no weapon		*/
	ufasssim 	/*  Number unfounded simple assaults		*/

	acmosrep 	/*  Number of months data for actual offenses*/
	acasstot 	/*  Number actual assaults total from FBI	*/
	acassagg 	/*  Calculated number actual agg assaults:	*/
			/*  ^assagg = ^assgun+^assknife+^assoweap+^assunarm*/
	acassall  	/*  Calculated number total actual assaults:	*/
			/*  ^assall = ^assagg +^asssimp			*/
	acassgun 	/*  Number actual assaults w-gun		*/
	acassknf 	/*  Number actual assaults w-knife		*/
	acassowp 	/*  Number actual assaults w-other weapon	*/
	acassnwp 	/*  Number actual assaults no weapon		*/
	acasssim 	/*  Number actual simple assaults		*/

	clmosrep 	/*  Number of months data for cleared offenses	*/
	classtot 	/*  Number cleared assaults total from FBI	*/
	classagg 	/*  Calculated number cleared agg assaults:	*/
			/*  ^assagg = ^assgun+^assknife+^assoweap+^assunarm*/
	classall  	/*  Calculated number total cleared assaults:	*/
			/*  ^assall = ^assagg +^asssimp			*/
	classgun 	/*  Number cleared assaults w-gun		*/
	classknf 	/*  Number cleared assaults w-knife		*/
	classowp 	/*  Number cleared assaults w-other weapon	*/
	classnwp 	/*  Number cleared assaults no weapon		*/
	classsim 	/*  Number cleared simple assaults		*/
	;

proc sort data=fbiyrly;
by ori year;

data bigori;
set fbiyrly;
by ori;
if first.ori;

data _null_;
set bigori;
file outori;
put  ori;

proc freq data=fbiyrly;
tables year;
title2 'Frequency of ORIs each year';

proc means data=fbiyrly maxdec=2;
var ufasstot--ufasssim acasstot--acasssim classtot--classsim;
title2 'Mean number of assaults per year per ORI';
